@@ -12,15 +12,7 @@ from pySRSLockin.plots import PlotObject
 graphics_dir = path.join(path.dirname(__file__), 'graphics')
 
 class interface():
-    output = {'X':0,'Y':0,'mag':0,'theta':0}
-    continuous_read = False #When this is set to True, the data from device are acquired continuosly at the rate set by self.refresh_time
-    refresh_time = 0.2 #default refresh rate, in seconds
-    stored_data = {'X':[],'Y':[],'mag':[],'theta':[]}  # List used to store recorded data
-    plot_window = None # QWidget object of the widget (i.e. floating window) that will contain the plot
-    plot_object = None # PlotObject object of the plot where self.store_powers is plotted
-    connected_device_name = ''
-    _verbose = True #Keep track of whether this instance of the interface should produce logs or not
-    _name_logger = ''
+    output = {'X':0,'Y':0,'mag':0,'theta':0} #We define this also as class variable, to make it possible to see which data is produced by this interface without having to create an object
 
     def __init__(self, app, mainwindow, parent, name_logger=__package__):
         # app           = The pyqt5 QApplication() object
@@ -34,6 +26,15 @@ class interface():
         self.parent = parent
         self.mainwindow.child = self #make sure that the window embedding this interface knows about its child (this is mainly used to link the closing events when using multiple windows)
  
+        self.output = {'X':0,'Y':0,'mag':0,'theta':0} #We define this also as class variable, to make it possible to see which data is produced by this interface without having to create an object
+        self.continuous_read = False #When this is set to True, the data from device are acquired continuosly at the rate set by self.refresh_time
+        self.refresh_time = 0.2 #default refresh rate, in seconds
+        self.stored_data = {'X':[],'Y':[],'mag':[],'theta':[]}  # List used to store recorded data
+        self.plot_window = None # QWidget object of the widget (i.e. floating window) that will contain the plot
+        self.plot_object = None # PlotObject object of the plot where self.store_powers is plotted
+        self.connected_device_name = ''
+        self._verbose = True #Keep track of whether this instance of the interface should produce logs or not
+        self._name_logger = ''
 
         self.instrument = SRS_Lockin() 
         self.name_logger = name_logger #Setting this property will also create the logger,set defaulat output style, and store the logger object in self.logger
@@ -504,7 +505,7 @@ class interface():
            
         return
 
-    def closeEvent(self):
+    def close(self):
         if (self.instrument.connected == True):
             self.disconnect_device()
     
@@ -517,7 +518,7 @@ class MainWindow(Qt.QWidget):
         # self.setCentralWidget(self.container)
     def closeEvent(self, event):
         if self.child:
-            self.child.closeEvent()
+            self.child.close()
 
 def main():
     parser = argparse.ArgumentParser(description = "",epilog = "")
@@ -528,7 +529,7 @@ def main():
     window = MainWindow()
     Interface = interface(app,window,window) #In this case window is both the MainWindow and the parent of the gui
     Interface.verbose = not(args.decrease_verbose)
-    app.aboutToQuit.connect(Interface.closeEvent) 
+    app.aboutToQuit.connect(Interface.close) 
     Interface.create_gui(plot=True)
     
     window.show()
